@@ -26,10 +26,11 @@ class Forward(BaseModel):
 
 class LiveSettings(BaseModel):
     delete_sync: bool = False
+    delete_on_edit: Optional[str] = None
 
 
 class PastSettings(BaseModel):
-    delay: Optional[int] = 0
+    delay: Optional[float] = 0
 
     @validator('delay')
     def validate_delay(cls, val):
